@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HTML-TEMPLATE-TEST; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/html-template/test.lisp,v 1.11 2006/09/29 22:36:26 edi Exp $
+;;; $Header: /usr/local/cvsrep/html-template/test.lisp,v 1.13 2007/01/01 23:49:16 edi Exp $
 
-;;; Copyright (c) 2003-2006, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2007, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -121,6 +121,12 @@
 (test "2" "<!-- TMPL_IF foo --><!-- TMPL_IF bar -->1<!-- TMPL_ELSE -->2<!-- /TMPL_IF --><!-- TMPL_ELSE --><!-- TMPL_IF baz -->3<!-- TMPL_ELSE -->4<!-- /TMPL_IF --><!-- /TMPL_IF -->" '(:foo t :bar nil))
 (test "3" "<!-- TMPL_IF foo --><!-- TMPL_IF bar -->1<!-- TMPL_ELSE -->2<!-- /TMPL_IF --><!-- TMPL_ELSE --><!-- TMPL_IF baz -->3<!-- TMPL_ELSE -->4<!-- /TMPL_IF --><!-- /TMPL_IF -->" '(:foo nil :baz t))
 (test "4" "<!-- TMPL_IF foo --><!-- TMPL_IF bar -->1<!-- TMPL_ELSE -->2<!-- /TMPL_IF --><!-- TMPL_ELSE --><!-- TMPL_IF baz -->3<!-- TMPL_ELSE -->4<!-- /TMPL_IF --><!-- /TMPL_IF -->" '(:foo nil :baz nil))
+(test "X" "<!-- TMPL_CALL foo -->" '(:foo (("X"))))
+(test "QUUX" "<!-- TMPL_VAR baz --><!-- TMPL_CALL foo -->" '(:baz "Q"
+                                                             :foo (("<!-- TMPL_VAR bar -->" :bar "U")
+                                                                   ("<!-- TMPL_VAR bar -->X" :bar "U"))))
+(test "" "<!-- TMPL_IF foo --><!-- TMPL_CALL bar --><!-- /TMPL_IF -->" '(:foo (("---"))))
+(test nil "<!-- TMPL_CALL foo -->" '(:foo 57))
 
 (let ((temp-name (make-pathname :name (format nil "template-test-~A" (random 1000000))
                                 :defaults tmp-dir)))
@@ -213,7 +219,11 @@
         "<!-- TMPL_LOOP vector -->[<!-- TMPL_VAR item -->]<!-- /TMPL_LOOP -->"
         '(:vector #((:item "1")
                     (:item "2")
-                    (:item "3")))))
+                    (:item "3"))))
+  (test "QUUX" "<!-- TMPL_VAR baz --><!-- TMPL_CALL foo -->"
+        '(:baz "Q"
+          :foo #(("<!-- TMPL_VAR bar -->" :bar "U")
+                 ("<!-- TMPL_VAR bar -->X" :bar "U")))))
 
 (let ((*upcase-attribute-strings* nil))
   (test "The slow brown fox"
